From 7ae21709bb6dbdc092052acb5098bfa5cb316d9e Mon Sep 17 00:00:00 2001
From: kenneth_suter <kenneth_suter@localhost>
Date: Thu, 29 Mar 2007 15:09:14 +0000
Subject: [PATCH] These refactorings are essential in anticipation of a new quicksetup application for the upgrader feature (issue 598).  These changes were reviewed by Josu. 

---
 opends/src/quicksetup/org/opends/quicksetup/UserDataException.java |   10 ++++------
 1 files changed, 4 insertions(+), 6 deletions(-)

diff --git a/opends/src/quicksetup/org/opends/quicksetup/installer/UserInstallDataException.java b/opends/src/quicksetup/org/opends/quicksetup/UserDataException.java
similarity index 88%
rename from opends/src/quicksetup/org/opends/quicksetup/installer/UserInstallDataException.java
rename to opends/src/quicksetup/org/opends/quicksetup/UserDataException.java
index 96d4a51..2fcf813 100644
--- a/opends/src/quicksetup/org/opends/quicksetup/installer/UserInstallDataException.java
+++ b/opends/src/quicksetup/org/opends/quicksetup/UserDataException.java
@@ -25,9 +25,7 @@
  *      Portions Copyright 2006-2007 Sun Microsystems, Inc.
  */
 
-package org.opends.quicksetup.installer;
-
-import org.opends.quicksetup.Step;
+package org.opends.quicksetup;
 
 /**
  * This exception is used when there is an error with the data provided by
@@ -35,7 +33,7 @@
  * the user data (QuickSetup).
  *
  */
-public class UserInstallDataException extends Exception
+public class UserDataException extends Exception
 {
   private static final long serialVersionUID = 1798143194655443132L;
 
@@ -44,11 +42,11 @@
   private String localizedMessage;
 
   /**
    * Constructor for UserInstallDataException.
    * @param step the step in the wizard where the exception occurred.
    * @param localizedMessage the localized message describing the error.
    */
-  public UserInstallDataException(Step step, String localizedMessage)
+  public UserDataException(Step step, String localizedMessage)
   {
     super(localizedMessage);
     this.step = step;
@@ -44,11 +42,11 @@
 
   /**
-   * Constructor for UserInstallDataException.
+   * Constructor for UserDataException.
    * @param step the step in the wizard where the exception occurred.
    * @param localizedMessage the localized message describing the error.

--
Gitblit v1.10.0